package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import com.bonus.material.ma.domain.Type;
import com.bonus.material.ma.domain.vo.MachineVo;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.Machine;
import com.bonus.material.ma.service.IMachineService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 机具设备管理Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "机具设备管理接口")
@RestController
@RequestMapping("/ma_machine")
public class MachineController extends BaseController {

    @Autowired
    private IMachineService machineService;

    /**
     * 查询机具设备管理列表
     */
    @ApiOperation(value = "查询机具设备管理列表1")
    //@RequiresPermissions("ma:machine:list")
    @GetMapping("/list")
    public TableDataInfo list(Machine machine)
    {
        startPage();
        List<MachineVo> list = machineService.selectMachineList(machine);
        return getDataTable(list);
    }

    /**
     * 查询机具设备管理列表
     */
    @ApiOperation(value = "查询机具设备管理列表2")
    //@RequiresPermissions("ma:machine:typeList")
    @GetMapping("/getTypeList")
    public AjaxResult list(Type type)
    {
        return machineService.selectByTypeList(type);
    }

    /**
     * 导出机具设备管理列表
     */
    @ApiOperation(value = "导出机具设备管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:machine:export")
    @SysLog(title = "机具设备管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出机具设备管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, Machine machine)
    {
        List<MachineVo> list = machineService.selectMachineList(machine);
        ExcelUtil<MachineVo> util = new ExcelUtil<MachineVo>(MachineVo.class);
        util.exportExcel(response, list, "机具设备管理数据");
    }

    /**
     * 获取机具设备管理详细信息
     */
    @ApiOperation(value = "获取机具设备管理详细信息")
    @RequiresPermissions("ma:machine:query")
    @GetMapping(value = "/{maId}")
    public AjaxResult getInfo(@PathVariable("maId") Long maId)
    {
        return AjaxResult.success(machineService.selectMachineByMaId(maId));
    }

    /**
     * 新增机具设备管理
     */
    @ApiOperation(value = "新增机具设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:machine:add")
    @SysLog(title = "机具设备管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增机具设备管理")
    @PostMapping
    public AjaxResult add(@RequestBody Machine machine)
    {
        return toAjax(machineService.insertMachine(machine));
    }

    /**
     * 修改机具设备管理
     */
    @ApiOperation(value = "修改机具设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:machine:edit")
    @SysLog(title = "机具设备管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改机具设备管理")
    @PutMapping
    public AjaxResult edit(@RequestBody Machine machine)
    {
        return machineService.updateMachine(machine);
    }

    /**
     * 删除机具设备管理
     */
    @ApiOperation(value = "删除机具设备管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:machine:remove")
    @SysLog(title = "机具设备管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除机具设备管理")
	@DeleteMapping("/{maId}")
    public AjaxResult remove(@PathVariable Long maId)
    {
        return machineService.deleteMachineByMaId(maId);
    }
}
